==> webpdf-wsclient-10.0.1-sources.jar: net/webpdf/wsclient/schema/operation/ReplyStateAnnotationType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p443889_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:p538622_="https://jakarta.ee/xml/ns/jaxb" xmlns:p701498_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;An annotation, that provides a "reply state" for a selected annotation.&lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for ReplyStateAnnotationType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="ReplyStateAnnotationType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/operation}BaseReplyType">
 *       <attribute name="replyState" type="{http://schema.webpdf.de/1.0/operation}ReplyState" default="none" />
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ReplyStateAnnotationType")
public class ReplyStateAnnotationType
    extends BaseReplyType
{

    /**
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p443889_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:p538622_="https://jakarta.ee/xml/ns/jaxb" xmlns:p701498_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Adds a reply state to the commented annotation.&#13;
     *                                 &lt;ul&gt;&lt;li&gt;accepted = The user agrees with the change.&lt;/li&gt;&lt;li&gt;rejected = The user disagrees with the change.&lt;/li&gt;&lt;li&gt;cancelled = The change has been cancelled.&lt;/li&gt;&lt;li&gt;completed = The change has been completed.&lt;/li&gt;&lt;li&gt;none = The user did not set a state.&lt;/li&gt;&lt;/ul&gt;&lt;/p&gt;
     * </pre>
     * 
     */
    @XmlAttribute(name = "replyState")
    protected ReplyState replyState;

    /**
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p443889_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:p538622_="https://jakarta.ee/xml/ns/jaxb" xmlns:p701498_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Adds a reply state to the commented annotation.&#13;
     *                                 &lt;ul&gt;&lt;li&gt;accepted = The user agrees with the change.&lt;/li&gt;&lt;li&gt;rejected = The user disagrees with the change.&lt;/li&gt;&lt;li&gt;cancelled = The change has been cancelled.&lt;/li&gt;&lt;li&gt;completed = The change has been completed.&lt;/li&gt;&lt;li&gt;none = The user did not set a state.&lt;/li&gt;&lt;/ul&gt;&lt;/p&gt;
     * </pre>
     * 
     * @return
     *     possible object is
     *     {@link ReplyState }
     *     
     */
    public ReplyState getReplyState() {
        if (replyState == null) {
            return ReplyState.NONE;
        } else {
            return replyState;
        }
    }

    /**
     * Sets the value of the replyState property.
     * 
     * @param value
     *     allowed object is
     *     {@link ReplyState }
     *     
     * @see #getReplyState()
     */
    public void setReplyState(ReplyState value) {
        this.replyState = value;
    }

    public boolean isSetReplyState() {
        return (this.replyState!= null);
    }

}

==> webpdf-wsclient-10.0.2-sources.jar: net/webpdf/wsclient/schema/operation/ReplyStateAnnotationType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p478056_="https://jakarta.ee/xml/ns/jaxb" xmlns:p587657_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p878301_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;An annotation, that provides a "reply state" for a selected annotation.&lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for ReplyStateAnnotationType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="ReplyStateAnnotationType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/operation}BaseReplyType">
 *       <attribute name="replyState" type="{http://schema.webpdf.de/1.0/operation}ReplyState" default="none" />
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ReplyStateAnnotationType")
public class ReplyStateAnnotationType
    extends BaseReplyType
{

    /**
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p478056_="https://jakarta.ee/xml/ns/jaxb" xmlns:p587657_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p878301_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Adds a reply state to the commented annotation.&#13;
     *                                 &lt;ul&gt;&lt;li&gt;accepted = The user agrees with the change.&lt;/li&gt;&lt;li&gt;rejected = The user disagrees with the change.&lt;/li&gt;&lt;li&gt;cancelled = The change has been cancelled.&lt;/li&gt;&lt;li&gt;completed = The change has been completed.&lt;/li&gt;&lt;li&gt;none = The user did not set a state.&lt;/li&gt;&lt;/ul&gt;&lt;/p&gt;
     * </pre>
     * 
     */
    @XmlAttribute(name = "replyState")
    protected ReplyState replyState;

    /**
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p478056_="https://jakarta.ee/xml/ns/jaxb" xmlns:p587657_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p878301_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Adds a reply state to the commented annotation.&#13;
     *                                 &lt;ul&gt;&lt;li&gt;accepted = The user agrees with the change.&lt;/li&gt;&lt;li&gt;rejected = The user disagrees with the change.&lt;/li&gt;&lt;li&gt;cancelled = The change has been cancelled.&lt;/li&gt;&lt;li&gt;completed = The change has been completed.&lt;/li&gt;&lt;li&gt;none = The user did not set a state.&lt;/li&gt;&lt;/ul&gt;&lt;/p&gt;
     * </pre>
     * 
     * @return
     *     possible object is
     *     {@link ReplyState }
     *     
     */
    public ReplyState getReplyState() {
        if (replyState == null) {
            return ReplyState.NONE;
        } else {
            return replyState;
        }
    }

    /**
     * Sets the value of the replyState property.
     * 
     * @param value
     *     allowed object is
     *     {@link ReplyState }
     *     
     * @see #getReplyState()
     */
    public void setReplyState(ReplyState value) {
        this.replyState = value;
    }

    public boolean isSetReplyState() {
        return (this.replyState!= null);
    }

}
